Skip to main contentModule claude
Source - AgentDecision
- The parsed decision from a Claude API response.
- ToolCall
- A tool call returned by Claude in a response.
- ToolDefinition
- Represents a tool definition sent to Claude API.
- ClaudeError
- Errors specific to the Claude API client.
- ClaudeModel
- All available Claude API models.
- call_claude
- Call Claude via motosan-ai and return a parsed AgentDecision.
- parse_agent_decision
- Parse a Claude API response JSON into an AgentDecision.
- trading_tools
- Returns the standard set of trading tool definitions for the Claude agent.