Structs
- Cancel
Order Tool - Close
AllPositions Tool - DoNothing
Tool - GetFunding
Rate Tool - GetMarket
Data Tool - GetOpen
Orders Tool - GetPositions
Tool - GetTrade
History Tool - Place
Order Tool - SetStop
Loss Tool - SetTake
Profit Tool
Functions
- fetch_
funding_ rate - Fetch the current funding rate for a symbol from Hyperliquid public API.
- fetch_
market_ data - Fetch L2 orderbook data for a symbol from Hyperliquid public API.
- fetch_
open_ orders - Fetch open orders from Hyperliquid public API.
- fetch_
trade_ history - Fetch trade history (user fills) from Hyperliquid public API.